/* See license.txt for terms of usage */

var AQwikWiki_Wikipedia = {};
var AQWIKWIKI_URL = 'wikipedia.org/wiki/Special:Search?search=';

AQwikWiki_Wikipedia.load = function( source, terms, resultHandler, AQwikWiki_Preferences_isHTML, AQwikWiki_Preferences_isBOLD ) {
	
	//
	// Format URL
	var url = "http://"+source+"."+AQWIKWIKI_URL + escape(terms.join('+'));		

	//
	// Set up frame that loads content
	var gdoc = content.document;
	var frame = gdoc.createElement('iframe');
	frame.style.width="1px";
	frame.style.height="0px";
	frame.style.top=0;
	frame.style.left=0;
	frame.style.position="fixed";
	frame.style.border="0";
	frame.src = url;
	frame.id = 'AQwikWiki_Wikipedia_FRAME';


	frame.addEventListener("load", 
			function (event) {
				try {			
					
					//
					// Grab results
					var doc = frame.contentDocument;
					if ( AQwikWiki_Wikipedia.hasResults( source, doc ) ) {
						if ( !AQwikWiki_Wikipedia.isDisambiguation( source, doc ) ) {								
							var firstParagraph = AQwikWiki_Wikipedia.getFirstParagraph( doc, AQwikWiki_Preferences_isHTML, AQwikWiki_Preferences_isBOLD );
							resultHandler( 1, firstParagraph,url );							
						} else {
							resultHandler( 2, "", url );
						}
					} else {
						resultHandler( 0, "", url );
					}
					
					//
					// Remove frame
					setTimeout(function (){
						gdoc.body.removeChild( frame );
					},10);


				} catch ( exp ) {
					AQwikWiki_Utilities.reportException( exp );
				}
				return true;
				}, true );	

	gdoc.body.appendChild( frame );		
}

AQwikWiki_Wikipedia.hasResults = function( source, document ) {
	if ( source=="en" ) {
		x=document.evaluate("//div[@id='bodyContent']/a[@id='No_article_title_matches']", document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null );
		return x.singleNodeValue==null;
	}
	if ( source=="fr" ) {
		x=document.evaluate("//div[@id='bodyContent']/a[@id='Aucun_titre_de_page_ne_correspond_.C3.A0_la_recherche']", document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null );
		return x.singleNodeValue==null;
	}
	if ( source=="de" ) {
		x=document.evaluate("//div[@id='bodyContent']/a[@id='Keine_.C3.9Cbereinstimmungen_mit_Seitentiteln']", document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null );
		return x.singleNodeValue==null;
	}
	if ( source=="es" ) {
		x=document.evaluate("//div[@id='bodyContent']/a[@id='No_hay_coincidencias_de_t.C3.ADtulo_de_art.C3.ADculo']", document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null );
		return x.singleNodeValue==null;
	}	
	return false;
}

AQwikWiki_Wikipedia.getFirstParagraph = function( doc, AQwikWiki_Preferences_isHTML, AQwikWiki_Preferences_isBOLD ) {
	var paragraph = doc.evaluate("//div[@id='bodyContent']/p", doc, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null );
	
	var res = "&nbsp;";
	x=paragraph.singleNodeValue;
	var MIN_WORDS = 40;	
	
	//
	// Iterativly add information
	while ( x!=null && x.id!="toc" && res.split(/\s+/).length<MIN_WORDS && x.tagName!="H2" ) {
		
		//
		// Only paragraph's text will be included
		if ( x.tagName=="P" ) {
			if ( AQwikWiki_Preferences_isHTML ) {
				if ( x.innerHTML ) {
					res = res + x.innerHTML;
				}
			} else {
				if ( x.textContent!=null ) {
					res = res + x.textContent + " ";
				}
			}
		}
		x=x.nextSibling;
	}
		
	if ( !AQwikWiki_Preferences_isHTML && AQwikWiki_Preferences_isBOLD ) {
		res = "<b>"+ res + "</b>";
	}
	
	return res;
}

AQwikWiki_Wikipedia.isDisambiguation = function( source, document ) {
	if ( source=="en" ) {
		x1=document.evaluate("//div[@id='bodyContent']/table[@id='disambig']", document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null );
		x2=document.evaluate("//div[@id='bodyContent']/table[@id='disambig_disambigbox']", document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null );
		return x1.singleNodeValue!=null || x2.singleNodeValue!=null;
	}
	if ( source=="fr" ) {
		x1=document.evaluate("//div[@id='bodyContent']/div[@class='homonymie']", document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null );
		return x1.singleNodeValue!=null;
	}
	if ( source=="de" ) {
		x1=document.evaluate("//div[@id='bodyContent']/table[@id='Vorlage_Begriffsklaerung']", document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null );
		return x1.singleNodeValue!=null;
	}
	if ( source=="es" ) {
		x1=document.evaluate("//div[@id='bodyContent']/table[@class='plainlinks ambox ambox-notice']", document, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null );
		return x1.singleNodeValue!=null;
	}
	
	return false;
}

