/* See license.txt for terms of usage */

var AQwikWiki_Preferences = {};

AQwikWiki_Preferences.load = function() {
	try {
		//
		// Load preferences
		var prefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
		prefs = prefs.getBranch("extensions.aqwikwiki.");
		AQwikWiki_Preferences.isHTML = prefs.getBoolPref("isHTML");
		AQwikWiki_Preferences.isBOLD = prefs.getBoolPref("isBOLD");
		AQwikWiki_Preferences.c1 = prefs.getCharPref("interleavingState");
		AQwikWiki_Preferences.c2 = prefs.getCharPref("interleavingState2");
		AQwikWiki_Preferences.bg1 = prefs.getCharPref("interleavingStateBG");
		AQwikWiki_Preferences.bg2 = prefs.getCharPref("interleavingStateBG2");
		AQwikWiki_Preferences.src = prefs.getCharPref("source");
		
		//
		// Update GUI
		document.getElementById("c1").color =  AQwikWiki_Preferences.c1;
		document.getElementById("c2").color =  AQwikWiki_Preferences.c2;
		document.getElementById("bg1").color =  AQwikWiki_Preferences.bg1;
		document.getElementById("bg2").color =  AQwikWiki_Preferences.bg2;
		document.getElementById('contentText').checked = !AQwikWiki_Preferences.isHTML;
		document.getElementById('contentTextBold').checked = AQwikWiki_Preferences.isBOLD;
		document.getElementById('WikiSource').value = AQwikWiki_Preferences.src;
		AQwikWiki_Preferences.updateGUI();
		
		//
		// Hook listeners
		document.getElementById("c1").addEventListener("change", AQwikWiki_Preferences.updateGUI , true );
		document.getElementById("c2").addEventListener("change", AQwikWiki_Preferences.updateGUI , true );
		document.getElementById("bg1").addEventListener("change", AQwikWiki_Preferences.updateGUI , true );
		document.getElementById("bg2").addEventListener("change", AQwikWiki_Preferences.updateGUI , true );
		document.getElementById('contentText').addEventListener("CheckboxStateChange", AQwikWiki_Preferences.updateGUI , true );
		
		//
		// Restore defaults
		document.getElementById('restoreDefaultsBtn').addEventListener('click', AQwikWiki_Preferences.restoreDefaults , true);
		
	} catch ( exp ) {
		AQwikWiki_Utilities.reportException( exp );
	}
}

AQwikWiki_Preferences.update = function() {
	try {
	
	//
	// Update configuration
	AQwikWiki_Preferences.isHTML = !document.getElementById("contentText").checked;
	AQwikWiki_Preferences.isBOLD = document.getElementById("contentTextBold").checked;
	AQwikWiki_Preferences.c1 = document.getElementById("c1").color;
	AQwikWiki_Preferences.c2 = document.getElementById("c2").color;
	AQwikWiki_Preferences.bg1 = document.getElementById("bg1").color;
	AQwikWiki_Preferences.bg2 = document.getElementById("bg2").color;
	AQwikWiki_Preferences.src = document.getElementById('WikiSource').value;
	
	//
	// Store preferences
	var pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
	pref = pref.getBranch("extensions.aqwikwiki.");
	pref.setBoolPref("isHTML", AQwikWiki_Preferences.isHTML);
	pref.setBoolPref("isBOLD", AQwikWiki_Preferences.isBOLD);
	pref.setCharPref("interleavingState", AQwikWiki_Preferences.c1);
	pref.setCharPref("interleavingState2", AQwikWiki_Preferences.c2);
	pref.setCharPref("interleavingStateBG", AQwikWiki_Preferences.bg1);
	pref.setCharPref("interleavingStateBG2", AQwikWiki_Preferences.bg2);
	pref.setCharPref("source", AQwikWiki_Preferences.src);

	//
	// Remove listeners
	document.getElementById("c1").removeEventListener("change", AQwikWiki_Preferences.updateGUI , true );
	document.getElementById("c2").removeEventListener("change", AQwikWiki_Preferences.updateGUI , true );
	document.getElementById("bg1").removeEventListener("change", AQwikWiki_Preferences.updateGUI , true );
	document.getElementById("bg2").removeEventListener("change", AQwikWiki_Preferences.updateGUI , true );
	document.getElementById('contentText').removeEventListener("CheckboxStateChange", AQwikWiki_Preferences.updateGUI , true );
	document.getElementById('restoreDefaultsBtn').removeEventListener('click', AQwikWiki_Preferences.restoreDefaults , true);
	} catch ( exp ) {
		AQwikWiki_Utilities.reportException( exp );
	}
}

AQwikWiki_Preferences.restoreDefaults = function(event) {
	document.getElementById("c1").color =  "black";
	document.getElementById("c2").color =  "black";
	document.getElementById("bg1").color =  "yellow";
	document.getElementById("bg2").color =  "#99FFFF";
	document.getElementById('contentText').checked = true;
	document.getElementById('contentTextBold').checked = true;
	document.getElementById('WikiSource').value = "en";

	AQwikWiki_Preferences.updateGUI();
}

AQwikWiki_Preferences.updateGUI = function( evt ) {
	
	try {
		
		//
		// Update example
		var c1 = document.getElementById("c1").color;
		var c2 = document.getElementById("c2").color;
		var bg1 = document.getElementById("bg1").color;
		var bg2 = document.getElementById("bg2").color;		
		var format1 = document.getElementById("format1");
		var format2 = document.getElementById("format2");
		format1.style.color = c1;
		format1.style.background = bg1;
		format2.style.color = c2;
		format2.style.background = bg2;		
		if ( document.getElementById('contentText').checked ) {
			document.getElementById('contentTextBold').disabled = false; 
		} else {
			document.getElementById('contentTextBold').disabled = true;			
		}
		
	} catch ( exp ) {
		AQwikWiki_Utilities.reportException( exp );
	}
}